@@ -1,7 +1,7 @@
 from googletrans import Translator
 import requests
 
-def chat(value):
-        response = requests.get("http://kenucheck.xyz/ai/api.php?msg=" + t.text)
+def chat(value, uid = 1):
+        response = requests.get("http://kenucheck.xyz/ai/api.php?uid=" + str(uid) +"&msg=" + value)
         veri = response.text.split(':"')[-1].split('"}')[0]
         return veri
\ No newline at end of file
